{******************************************************************************}
{ Jazarsoft DesktopTheme Component                                             }
{******************************************************************************}
{                                                                              }
{ VERSION      : 1.0                                                           }
{ AUTHOR       : James Azarja (jazar@jazarsoft.cjb.net)                        }
{ CREATED      : 15 July 2000                                                  }
{ WEBSITE      : http://jazarsoft.cjb.net/                                     }
{ SUPPORT      : support@jazarsoft.cjb.net                                     }
{ BUG-REPORT   : bugreport@jazarsoft.cjb.net                                   }
{ COMMENT      : comment@jazarsoft.cjb.net                                     }
{ LEGAL        : Copyright (C) 2000 Jazarsoft.                                 }
{                                                                              }
{******************************************************************************}
{ NOTE         :                                                               }
{                                                                              }
{ This code may be used and modified by anyone so long as  this header and     }
{ copyright  information remains intact.                                       }
{                                                                              }
{ The code is provided "as-is" and without warranty of any kind,               }
{ expressed, implied or otherwise, including and without limitation, any       }
{ warranty of merchantability or fitness for a  particular purpose.           }
{                                                                              }
{ In no event shall the author be liable for any special, incidental,          }
{ indirect or consequential damages whatsoever (including, without             }
{ limitation, damages for loss of profits, business interruption, loss         }
{ of information, or any other loss), whether or not advised of the            }
{ possibility of damage, and on any theory of liability, arising out of        }
{ or in connection with the use or inability to use this software.           }
{                                                                              }
{******************************************************************************}
{ KNOWN BUG :								       }
{									       }
{ - METRICS        							       }
{									       }
{******************************************************************************}
{ If you modify this code, please send it to jazar@jazarsoft.cjb.net	       }
{******************************************************************************}

unit DesktopTheme;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, Registry, IniFiles, ExtCtrls, JPEG;
     

type
  TWallpaperStyle = (wlpsCenter, wlpsTile, wlpsStretch);
  
  TMetrics = Class(TPersistent)
  private
   FIconMetrics      : String;
   FNonClientMetrics : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   Procedure Apply;
  published
   property IconMetrics      : String read FIconMetrics      Write FIconMetrics;
   Property NonClientMetrics : String read FNonClientMetrics Write FNonClientMetrics;
  end;

  TScreenSaver = Class(TPersistent)
  private
   FScreenSaver  : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   procedure Apply;
  published
   property ScreenSaver : String Read FScreenSaver Write FScreenSaver;
  end;

  TDesktop = Class(TPersistent)
  private
   FWallpaperStyle : tWallpaperStyle;
   FWallpaper : String;
   FPattern   : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   procedure Apply;
  published
   property Wallpaper          : String  Read FWallpaper Write FWallpaper;
   property Pattern            : String  Read FPattern   Write Fpattern;
   property WallpaperStyle     : tWallpaperStyle Read FWallpaperStyle Write FWallpaperStyle;
  end;

  TCursors = Class(TPersistent)
  private
   FArrow        : String;
   FHelp         : String;
   FAppStarting  : String;
   FWait         : String;
   FNWPen        : String;
   FNo           : String;
   FSizeNS       : String;
   FSizeWE       : String;
   FCrossHair    : String;
   FIBeam        : String;
   FSizeNWSE     : String;
   FSizeNESW     : String;
   FSizeAll      : String;
   FUpArrow      : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   Procedure Apply;
  published
   property Arrow        : String read FArrow        write FArrow;
   property Help         : String read FHelp         write FHelp;
   property AppStarting  : String read FAppStarting  write FAppStarting;
   property Wait         : String read FWait         write FWait;
   property NWPen        : String read FNWPen        write FNWPen;
   property No           : String read FNo           write FNo;
   property SizeNS       : String read FSizeNS       write FSizeNS;
   property SizeWE       : String read FSizeWE       write FSizeWE;
   property CrossHair    : String read FCrossHair    write FCrossHair;
   property IBeam        : String read FIBeam        write FIBeam;
   property SizeNWSE     : String read FSizeNWSE     write FSizeNWSE;
   property SizeNESW     : String read FSizeNESW     write FSizeNESW;
   property SizeAll      : String read FSizeAll      write FSizeAll;
   property UpArrow      : String read FUpArrow      write FUpArrow;
  end;

  TColors = Class(TPersistent)
  private
   FActiveTitle    : String;
   FBackground     : String;
   FHilight        : String;
   FHilightText    : String;
   FTitleText      : String;
   FWindow         : String;
   FWindowText     : String;
   FScrollbar      : String;
   FInactiveTitle  : String;
   FMenu           : String;
   FWindowFrame    : String;
   FMenuText       : String;
   FActiveBorder   : String;
   FInactiveBorder : String;
   FAppWorkspace   : String;
   FButtonFace     : String;
   FButtonShadow   : String;
   FGrayText       : String;
   FButtonText     : String;
   FInactiveTitleText : String;
   FButtonHilight  : String;
   FButtonDkShadow : String;
   FButtonLight    : String;
   FInfoText       : String;
   FInfoWindow     : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   procedure Apply;
  published
   property ActiveTitle        : string read FActiveTitle          write FActiveTitle;
   property Background         : string read FBackground           write FBackground;
   property Hilight            : string read FHilight              write FHilight;
   property HilightText        : string read FHilightText          write FHilightText;
   property TitleText          : string read FTitleText            write FTitleText;
   property Window             : string read FWindow               write FWindow;
   property WindowText         : string read FWindowText           write FWindowText;
   property Scrollbar          : string read FScrollbar            write FScrollbar;
   property InactiveTitle      : string read FInactiveTitle        write FInactiveTitle;
   property Menu               : string read FMenu                 write FMenu;
   property WindowFrame        : string read FWindowFrame          write FWindowFrame;
   property MenuText           : string read FMenuText             write FMenuText;
   property ActiveBorder       : string read FActiveBorder         write FActiveBorder;
   property InactiveBorder     : string read FInactiveBorder       write FInactiveBorder;
   property AppWorkspace       : string read FAppWorkspace         write FAppWorkspace;
   property ButtonFace         : string read FButtonFace           write FButtonFace;
   property ButtonShadow       : string read FButtonShadow         write FButtonShadow;
   property GrayText           : string read FGrayText             write FGrayText;
   property ButtonText         : string read FButtonText           write FButtonText;
   property InactiveTitleText  : string read FInactiveTitleText    write FInactiveTitleText;
   property ButtonHilight      : string read FButtonHilight        write FButtonHilight;
   property ButtonDkShadow     : string read FButtonDkShadow       write FButtonDkShadow;
   property ButtonLight        : string read FButtonLight          write FButtonLight;
   property InfoText           : string read FInfoText             write FInfoText;
   property InfoWindow         : string read FInfoWindow           write FInfoWindow;
  end;

  TIcons = Class(TPersistent)
  private
   FMyComputer   : String;
   FNetHood      : String;
   FRecycle      : String;
   FRecycleFull  : String;
   FRecycleEmpty : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   procedure Apply;
  published
   property MyComputer   : String Read FMyComputer   Write FMyComputer;
   property NetHood      : String Read FNetHood      Write FNetHood;
   property Recycle      : String Read FRecycle      Write FRecycle;
   property RecycleFull  : String Read FRecycleFull  Write FRecycleFull;
   property RecycleEmpty : String Read FRecycleEmpty Write FRecycleEmpty;
  end;

  TSounds = Class(TPersistent)
  private
   FDefault		: String;
   FAppGPFault		: String;
   FMaximize		: String;
   FMenuCommand		: String;
   FMenuPopup           : String;
   FMinimize		: String;
   FOpen                : String;
   FClose               : String;
   FRestoreDown         : String;
   FRestoreUp           : String;
   FRingIn		: String;
   FRingout             : String;
   FSystemAsterisk      : String;
   FSystemDefault       : String;
   FSystemExclamation   : String;
   FSystemExit		: String;
   FSystemHand          : String;
   FSystemQuestion      : String;
   FSystemStart         : String;
   FEmptyRecycleBin     : String;
  protected
  public
   constructor Create;
   destructor Destroy;override;
   procedure Refresh;
   procedure Apply;
  published
   Property Default		: String Read FDefault		        Write FDefault;
   Property AppGPFault		: String Read FAppGPFault		Write FAppGPFault;
   Property Maximize		: String Read FMaximize		 	Write FMaximize;		
   Property MenuCommand		: String Read FMenuCommand		Write FMenuCommand;
   Property MenuPopup           : String Read FMenuPopup                Write FMenuPopup;            
   Property Minimize		: String Read FMinimize		 	Write FMinimize;		
   Property Open                : String Read FOpen                     Write FOpen;                 
   Property Close               : String Read FClose                    Write FClose;                
   Property RestoreDown         : String Read FRestoreDown              Write FRestoreDown;          
   Property RestoreUp           : String Read FRestoreUp                Write FRestoreUp;             
   Property RingIn		: String Read FRingIn		        Write FRingIn;
   Property Ringout             : String Read FRingout                  Write FRingout;              
   Property SystemAsterisk      : String Read FSystemAsterisk           Write FSystemAsterisk;     
   Property SystemDefault       : String Read FSystemDefault            Write FSystemDefault;        
   Property SystemExclamation   : String Read FSystemExclamation        Write FSystemExclamation;    
   Property SystemExit		: String Read FSystemExit		Write FSystemExit;		
   Property SystemHand          : String Read FSystemHand               Write FSystemHand;           
   Property SystemQuestion      : String Read FSystemQuestion           Write FSystemQuestion;       
   Property SystemStart         : String Read FSystemStart              Write FSystemStart;          
   Property EmptyRecycleBin     : String Read FEmptyRecycleBin          Write FEmptyRecycleBin;  
  End;
  
  TDesktopTheme = class(TComponent)
  private
    FCursors      : TCursors;
    FColors       : TColors;
    FIcons        : tIcons;
    FSounds       : tSounds;
    FDesktop      : tDesktop;
    FScreenSaver  : tScreenSaver;
    FMetrics      : tMetrics;
  protected
    Function InsertRealDir(Str:String):String;
    Function InsertVarDir (Str:String):String;
  public
    WindowsDir    : String;
    PlusDir       : String;
    ThemesDir     : String;

    constructor Create(AOwner: TComponent); override;
    destructor  Destroy; override;
    Procedure   UpdateWindow;

    Procedure   LoadFromFile(Filename:String);
    Procedure   SaveToFile  (Filename:String);

    Procedure   Apply;
    Procedure   Refresh;
  published
    property Cursors     : tCursors  Read FCursors Write FCursors;
    property Colors      : tColors  Read FColors Write FColors;
    property Icons       : tIcons Read FIcons Write FIcons;
    property Sounds      : tSounds Read FSounds Write FSounds;
    property Desktop     : tDesktop Read FDesktop Write FDesktop;
    property ScreenSaver : tScreenSaver Read FScreenSaver Write FScreenSaver;
    property Metrics     : tMetrics     Read FMetrics     Write FMetrics;
  end;

procedure Register;

implementation

Type
 tRGB                    = Record
                            R, G, B : Byte;
                           End;

Function Replacestr(Str,Old,New:String):String;
var I : Integer;
    St:String;
    USt: String;
begin
 St:=Str;
 USt:=UpperCase(St);
 I:=Pos(Uppercase(Old),USt);
 While I<>0 do
 Begin
  Delete(St,I,Length(Old));
  If New<>'' then insert(New,St,I{-1});
  I:=Pos(Old,St);
 End;
 Result:=St;
end;

Function RGBtoColor(RGB:TRGB):TColor;
Begin
 Result:=Windows.RGB(RGB.R,RGB.G,RGB.B);
End;

Function ColorToRGB(Color:TColor):TRGB;
Begin
 Result.R:=GetRValue(Color);
 Result.G:=GetGValue(Color);
 Result.B:=GetBValue(Color);
End;

Function RGBToStr(RGB:TRGB):String;
Begin
 Result:=IntToStr(RGB.R)+' '+IntToStr(RGB.G)+' '+IntTOStr(RGB.B);
End;

Function StrToRGB(St:String):TRGB;
Begin
 Try
 Result.R:=StrToInt(Copy(St,1,Pos(' ',St)-1));
 Except
  On EConvertError do  Result.R:=0;
 End;
 Delete(St,1,Pos(' ',St));
 Try
 Result.G:=StrToInt(Copy(St,1,Pos(' ',St)-1));
 Except
  On EConvertError do  Result.G:=0;
 End;
 Delete(St,1,Pos(' ',St));
 Try
  If Pos(' ',St)=0 then
   Result.B:=StrToInt(Copy(St,1,Length(St))) else
   Result.B:=StrToInt(Copy(St,1,Pos(' ',St)-1));
 Except
  On EConvertError do  Result.B:=0;
 End;
 Delete(St,1,Pos(' ',St));
End;

Procedure JPG2BMP(JPEGFile:String;BitmapFile:String);
Var
 BMP    : TBitmap;
 Buffer : TImage;
 Temp   : Boolean;

begin
 Buffer:=TImage.Create(Application);
 With Buffer do
 Try
  Try
   Picture.LoadFromFile(JPEGFile);
  except
   on EInvalidGraphic do
     Exit;
  End;
  Temp := Picture.Graphic is TJPEGImage;
  if Temp then
    with TJPEGImage(Picture.Graphic) do
    begin
      Smoothing:=True;
    end;
  BMP:=TBitmap.Create;
  With BMP do
  Try
   Assign(Buffer.Picture.Graphic);
   SaveToFile(BitmapFile);
  Finally
   Free;
  End
 Finally
  Free;
 End;
End;

constructor TMetrics.Create;
Begin
  inherited Create;
End;

destructor TMetrics.Destroy;
Begin
  inherited Destroy;
End;

procedure TMetrics.Refresh;
var
 NCM : tNONCLIENTMETRICS;
 IM  : tICONMETRICS;
 
 Buffer: Array of Byte;
 Str   : String;
 Count: Integer;
Begin
 Str:='';
 NCM.cbSize:=SizeOF(NCM);
 SystemParametersInfo(SPI_GETNONCLIENTMETRICS,sizeof(NCM),@NCM,0);
 SetLength(Buffer,SizeOF(NCM));
 Move(NCM,Buffer[0],SizeOf(NCM));
 For Count:=0 to SizeOf(NCM)-1 do
  Str:=Str+' '+Inttostr(Buffer[Count]);
 FNonClientMetrics:=Str;

 Str:='';
 IM.cbSize:=SizeOF(IM);

 SystemParametersInfo(SPI_GETICONMETRICS,sizeof(IM),@IM,0);
 SetLength(Buffer,SizeOF(IM));
 Move(IM,Buffer[0],SizeOf(IM));
 For Count:=0 to SizeOf(IM)-1 do
  Str:=Str+Inttostr(Buffer[Count])+' ';
 FIconMetrics:=Str;
End;

procedure TMetrics.Apply;
var
 NCM : tNONCLIENTMETRICS;
 IM  : tICONMETRICS;

 Buffer: Array of Byte;
 Str   : String;
 Count: Integer;
Begin
 Str:=FIconMetrics;
 While Pos(' ',Str)<>0 do
 Begin
  SetLength(Buffer,Length(Buffer)+1);
  Buffer[Length(Buffer)-1]:=StrToInt(Copy( Str,1, Pos(' ',Str)-1 ));
  Delete(Str,1,Pos(' ',Str));
 end;

 If Str<>'' then
 begin
  SetLength(Buffer,Length(Buffer)+1);
  Buffer[Length(Buffer)-1]:=StrToInt(Str);
 End;

 Move(Buffer,IM,SizeOf(IM));
 SystemParametersInfo(SPI_SETICONMETRICS,SizeOf(IM),@IM,SPIF_SENDWININICHANGE);

 Str:=FNonClientMetrics;
 While Pos(' ',Str)<>0 do
 Begin
  SetLength(Buffer,Length(Buffer)+1);
  Buffer[Length(Buffer)-1]:=StrToInt(Copy( Str,1, Pos(' ',Str)-1 ));
  Delete(Str,1,Pos(' ',Str));
 end;

 If Str<>'' then
 begin
  SetLength(Buffer,Length(Buffer)+1);
  Buffer[Length(Buffer)-1]:=StrToInt(Str);
 End;
 Move(buffer,NCM,SizeOF(NCM));
 SystemParametersInfo(SPI_SETNONCLIENTMETRICS,SizeOf(NCM),@NCM,SPIF_SENDWININICHANGE);
End;


constructor TCursors.Create;
Begin
  inherited Create;
End;

destructor TCursors.Destroy;
Begin
  inherited Destroy;
End;

procedure TCursors.Refresh;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  If OpenKey('Control Panel\Cursors',False) then
  Begin
   If ValueExists('Arrow') then
    FArrow:=ReadString('Arrow') else FArrow:='';
    
   If ValueExists('Help') then
    FHelp:=ReadString('Help') else FHelp:='';

   If ValueExists('AppStarting') then
    FAppStarting:=ReadString('AppStarting') else FAppStarting:='';

   If ValueExists('Wait') then
    FWait:=ReadString('Wait') else FWait:='';

   If ValueExists('NWPen') then
    FNWPen:=ReadString('NWPen') else FNWPen:='';

   If ValueExists('No') then
    FNo:=ReadString('No') else FNo:='';

   If ValueExists('SizeNS') then
    FSizeNS:=ReadString('SizeNS') else FSizeNS:='';

   If ValueExists('SizeWE') then
    FSizeWE:=ReadString('SizeWE') else FSizeWE:='';

   If ValueExists('Crosshair') then
    FCrosshair:=ReadString('Crosshair') else FCrosshair:='';

   If ValueExists('IBeam') then
    FIBeam:=ReadString('IBeam') else FIBeam:='';

   If ValueExists('SizeNWSE') then
    FSizeNWSE:=ReadString('SizeNWSE') else FSizeNWSE:='';

   If ValueExists('SizeNESW') then
    FSizeNESW:=ReadString('SizeNESW') else FSizeNESW:='';

   If ValueExists('SizeAll') then
    FSizeAll:=ReadString('SizeAll') else FSizeAll:='';

   If ValueExists('UpArrow') then
    FUpArrow:=ReadString('UpArrow') else FSizeAll:='';
   CloseKey;
  End;
 Finally
  Free;
 End;
End;

procedure TCursors.Apply;
Begin
 With TRegistry.Create do
 Try  
  RootKey:=HKEY_CURRENT_USER;
  If OpenKey('Control Panel\Cursors',True) then
  Begin
   WriteString('Arrow',FArrow);
   WriteString('Help',FHelp);
   WriteString('AppStarting',FAppStarting);
   WriteString('Wait',FWait);
   WriteString('NWPen',FNWPen);
   WriteString('No',FNo);
   WriteString('SizeNS',FSizeNS);
   WriteString('SizeWE',FSizeWE);
   WriteString('Crosshair',FCrosshair);
   WriteString('IBeam',FIBeam);
   WriteString('SizeNWSE',FSizeNWSE);
   WriteString('SizeNESW',FSizeNESW);
   WriteString('SizeAll',FSizeAll);
   WriteString('UpArrow',FUpArrow);
  End;
  CloseKey;
 Finally
  Free;
 End;

 SetSystemCursor(LoadCursorFromFile(Pchar(FArrow)),OCR_NORMAL);
 SetSystemCursor(LoadCursorFromFile(Pchar(FIBeam)),OCR_IBEAM);
 SetSystemCursor(LoadCursorFromFile(Pchar(FWait)),OCR_WAIT);
 SetSystemCursor(LoadCursorFromFile(Pchar(FCrossHair)),OCR_CROSS);
 SetSystemCursor(LoadCursorFromFile(Pchar(FUpArrow)),OCR_UP);

 SetSystemCursor(LoadCursorFromFile(Pchar(FHelp)),OCR_SIZE);
 SetSystemCursor(LoadCursorFromFile(Pchar(FWait)),OCR_ICON);

 SetSystemCursor(LoadCursorFromFile(Pchar(FSizeNWSE)),OCR_SIZENWSE);
 SetSystemCursor(LoadCursorFromFile(Pchar(FSizeNESW)),OCR_SIZENESW);
 SetSystemCursor(LoadCursorFromFile(Pchar(FSizeWE)),OCR_SIZEWE);
 SetSystemCursor(LoadCursorFromFile(Pchar(FSizeNS)),OCR_SIZENS);
 SetSystemCursor(LoadCursorFromFile(Pchar(FSizeAll)),OCR_SIZEALL);
 SetSystemCursor(LoadCursorFromFile(Pchar(FNo)),OCR_NO);
 SetSystemCursor(LoadCursorFromFile(Pchar(FAppStarting)),OCR_APPSTARTING);
End;


constructor TColors.Create;
Begin
  inherited Create;
End;

destructor TColors.Destroy;
Begin
  inherited Destroy;
End;

procedure TColors.Refresh;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  If OpenKey('Control Panel\Colors',False) then
  Begin
   If ValueExists('ActiveTitle') then                             
    FActiveTitle:=ReadString('ActiveTitle') else FActiveTitle:='';
    
   If ValueExists('Background') then
    FBackground:=ReadString('Background') else FBackground:='';
    
   If ValueExists('Hilight') then
    FHilight:=ReadString('Hilight') else FHilight:='';

   If ValueExists('HilightText') then
    FHilightText:=ReadString('HilightText') else FHilightText:='';

   If ValueExists('TitleText') then
    FTitleText:=ReadString('TitleText') else FTitleText:='';

   If ValueExists('Window') then
    FWindow:=ReadString('Window') else FWindow:='';

   If ValueExists('WindowText') then
    FWindowText:=ReadString('WindowText') else FWindowText:='';

   If ValueExists('Scrollbar') then
    FScrollbar:=ReadString('Scrollbar') else FScrollbar:='';

   If ValueExists('InactiveTitle') then
    FInactiveTitle:=ReadString('InactiveTitle') else FInactiveTitle:='';

   If ValueExists('Menu') then
    FMenu:=ReadString('Menu') else FMenu:='';

   If ValueExists('WindowFrame') then
    FWindowFrame:=ReadString('WindowFrame') else FWindowFrame:='';

   If ValueExists('MenuText') then
    FMenuText:=ReadString('MenuText') else FMenuText:='';

   If ValueExists('ActiveBorder') then
    FActiveBorder:=ReadString('ActiveBorder') else FActiveBorder:='';

   If ValueExists('InactiveBorder') then
    FInactiveBorder:=ReadString('InactiveBorder') else FInactiveBorder:='';

   If ValueExists('AppWorkspace') then
    FAppWorkspace:=ReadString('AppWorkspace') else FAppWorkspace:='';

   If ValueExists('ButtonFace') then
    FButtonFace:=ReadString('ButtonFace') else FButtonFace:='';

   If ValueExists('ButtonShadow') then
    FButtonShadow:=ReadString('ButtonShadow') else FButtonShadow:='';

   If ValueExists('GrayText') then
    FGrayText:=ReadString('GrayText') else FGrayText:='';

   If ValueExists('ButtonText') then
    FButtonText:=ReadString('ButtonText') else FButtonText:='';

   If ValueExists('InactiveTitleText') then
    FInactiveTitleText:=ReadString('InactiveTitleText') else FInactiveTitleText:='';

   If ValueExists('ButtonHilight') then
    FButtonHilight:=ReadString('ButtonHilight') else FButtonHilight:='';

   If ValueExists('ButtonDkShadow') then
    FButtonDkShadow:=ReadString('ButtonDkShadow') else FButtonDkShadow:='';

   If ValueExists('ButtonLight') then
    FButtonLight:=ReadString('ButtonLight') else FButtonLight:='';

   If ValueExists('InfoText') then
    FInfoText:=ReadString('InfoText') else FInfoText:='';

   If ValueExists('InfoWindow') then
    FInfoWindow:=ReadString('InfoWindow') else FInfoWindow:='';
   CloseKey;
  End;
 Finally
  Free;
 End;
End;


procedure TColors.Apply;
const ElementsTotal  = 26;
var Color :array [1..ElementsTotal] of dword;
    Elements : array [1..ElementsTotal] of integer;
begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  If OpenKey('Control Panel\Colors',True) then
  Begin
   WriteString('ActiveTitle',FActiveTitle);
   WriteString('Background',FBackground);
   WriteString('Hilight',FHilight);
   WriteString('HilightText',FHilightText);
   WriteString('TitleText',FTitleText);
   WriteString('Window',FWindow);
   WriteString('WindowText',FWindowText);
   WriteString('Scrollbar',FScrollbar);
   WriteString('InactiveTitle',FInactiveTitle);
   WriteString('Menu',FMenu);
   WriteString('WindowFrame',FWindowFrame);
   WriteString('MenuText',FMenuText);
   WriteString('ActiveBorder',FActiveBorder);
   WriteString('InactiveBorder',FInactiveBorder);
   WriteString('AppWorkspace',FAppWorkspace);
   WriteString('ButtonFace',FButtonFace);
   WriteString('ButtonShadow',FButtonShadow);
   WriteString('GrayText',FGrayText);
   WriteString('ButtonText',FButtonText);
   WriteString('InactiveTitleText',FInactiveTitleText);
   WriteString('ButtonHilight',FButtonHilight);
   WriteString('ButtonDkShadow',FButtonDkShadow);
   WriteString('ButtonLight',FButtonLight);
   WriteString('InfoText',FInfoText);
   WriteString('InfoWindow',FInfoWindow);

  End;
  CloseKey;
 Finally
  Free;
 End;

 Color[1]:=RGBToColor(StrToRGB(FActiveTitle));
 Elements[1]:=COLOR_ACTIVECAPTION;

 Color[2]:=RGBToColor(StrToRGB(FBackground));
 Elements[2]:=COLOR_BACKGROUND;

 Color[3]:=RGBToColor(StrToRGB(FHilight));
 Elements[3]:=COLOR_HIGHLIGHT;

 Color[4]:=RGBToColor(StrToRGB(FHilightText));
 Elements[4]:=COLOR_HIGHLIGHTTEXT;

 Color[5]:=RGBToColor(StrToRGB(FTitleText));
 Elements[5]:=COLOR_CAPTIONTEXT;

 Color[6]:=RGBToColor(StrToRGB(FWindow));
 Elements[6]:=COLOR_WINDOW;

 Color[7]:=RGBToColor(StrToRGB(FWindowText));
 Elements[7]:=COLOR_WINDOWTEXT;

 Color[7]:=RGBToColor(StrToRGB(FScrollbar));
 Elements[7]:=COLOR_SCROLLBAR;

 Color[8]:=RGBToColor(StrToRGB(FMenu));
 Elements[8]:=COLOR_MENU;

 Color[9]:=RGBToColor(StrToRGB(FWindowFrame));
 Elements[9]:=COLOR_WINDOWFRAME;

 Color[10]:=RGBToColor(StrToRGB(FMenuText));
 Elements[10]:=COLOR_MENUTEXT;

 Color[11]:=RGBToColor(StrToRGB(FActiveBorder));
 Elements[11]:=COLOR_ACTIVEBORDER;

 Color[12]:=RGBToColor(StrToRGB(FActiveBorder));
 Elements[12]:=COLOR_ACTIVEBORDER;

 Color[13]:=RGBToColor(StrToRGB(FInActiveBorder));
 Elements[13]:=COLOR_INACTIVEBORDER;

 Color[14]:=RGBToColor(StrToRGB(FAppWorkspace));
 Elements[14]:=COLOR_APPWORKSPACE;

 Color[15]:=RGBToColor(StrToRGB(FButtonFace));
 Elements[15]:=COLOR_BTNFACE;

 Color[16]:=RGBToColor(StrToRGB(FButtonShadow));
 Elements[16]:=COLOR_BTNSHADOW;

 Color[17]:=RGBToColor(StrToRGB(FGrayText));
 Elements[17]:=COLOR_GRAYTEXT;

 Color[18]:=RGBToColor(StrToRGB(FButtonText));
 Elements[18]:=COLOR_BTNTEXT;

 Color[19]:=RGBToColor(StrToRGB(FInactiveTitleText));
 Elements[19]:=COLOR_INACTIVECAPTIONTEXT;

 Color[20]:=RGBToColor(StrToRGB(FButtonHilight));
 Elements[20]:=COLOR_BTNHILIGHT;

 Color[21]:=RGBToColor(StrToRGB(FButtonDkShadow));
 Elements[21]:=COLOR_3DDKSHADOW;

 Color[22]:=RGBToColor(StrToRGB(FButtonLight));
 Elements[22]:=COLOR_3DLIGHT;

 Color[23]:=RGBToColor(StrToRGB(FInfoText));
 Elements[23]:=COLOR_INFOTEXT;

 Color[24]:=RGBToColor(StrToRGB(FInfoWindow));
 Elements[24]:=COLOR_INFOBK;

 Color[25]:=RGBToColor(StrToRGB(FInactiveTitle));
 Elements[25]:=COLOR_INACTIVECAPTION;

 Color[26]:=RGBToColor(StrToRGB(FButtonFace));
 Elements[26]:=COLOR_3DFACE;

 SetSysColors(ElementsTotal,Elements,Color);
End;


constructor TIcons.Create;
Begin
  inherited Create;
End;

destructor TIcons.Destroy;
Begin
  inherited Destroy;
End;

procedure TIcons.Refresh;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  if OpenKey('Software\Classes\CLSID\{20D04FE0-3AEA-1069-A2D8-08002B30309D}\DefaultIcon',false) then
  Begin
   FMyComputer:=ReadString('');
   CloseKey;
  End;

  if OpenKey('Software\Classes\CLSID\{208D2C60-3AEA-1069-A2D7-08002B30309D}\DefaultIcon',false) then
  Begin
   FNetHood:=ReadString('');
   CloseKey;
  End;

  if OpenKey('Software\Classes\CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon',false) then
  Begin
   FRecycle:=ReadString('');
   FRecycleFull:=ReadString('full');
   FRecycleEmpty:=ReadString('empty');
   CloseKey;
  End;

 Finally
  Free;
 End;
End;

procedure TIcons.Apply;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  if OpenKey('Software\Classes\CLSID\{20D04FE0-3AEA-1069-A2D8-08002B30309D}\DefaultIcon',True) then
  Begin
   WriteString('',FMyComputer);
   CloseKey;
  End;

  if OpenKey('Software\Classes\CLSID\{208D2C60-3AEA-1069-A2D7-08002B30309D}\DefaultIcon',True) then
  Begin
   WriteString('',FNetHood);
   CloseKey;
  End;

  if OpenKey('Software\Classes\CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon',false) then
  Begin
   WriteString('',FRecycle);
   WriteString('full',FRecycleFull);
   WriteString('empty',FRecycleEmpty);
   CloseKey;
  End;

 Finally
  Free;
 End;
End;

constructor TSounds.Create;
Begin
  inherited Create;
End;

destructor TSounds.Destroy;
Begin
  inherited Destroy;
End;

procedure TSounds.Refresh;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;

  If OpenKey('AppEvents\Schemes\Apps\.Default\.Default\.Current',False) then
  Begin
   FDefault:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\AppGPFault\.Current',False) then
  Begin
   FAppGPFault:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Maximize\.Current',False) then
  Begin
   FMaximize:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\MenuCommand\.Current',False) then
  Begin
   FMenuCommand:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\MenuPopup\.Current',False) then
  Begin
   FMenuPopup:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Minimize\.Current',False) then
  Begin
   FMinimize:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Open\.Current',False) then
  Begin
   FOpen:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Close\.Current',False) then
  Begin
   FClose:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RestoreDown\.Current',False) then
  Begin
   FRestoreDown:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RestoreUp\.Current',False) then
  Begin
   FRestoreUp:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RingIn\.Current',False) then
  Begin
   FRingIn:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Ringout\.Current',False) then
  Begin
   FRingout:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemAsterisk\.Current',False) then
  Begin
   FSystemAsterisk:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemDefault\.Current',False) then
  Begin
   FSystemDefault:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemExclamation\.Current',False) then
  Begin
   FSystemExclamation:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemExit\.Current',False) then
  Begin
   FSystemExit:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemHand\.Current',False) then
  Begin
   FSystemHand:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemQuestion\.Current',False) then
  Begin
   FSystemQuestion:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemStart\.Current',False) then
  Begin
   FSystemStart:=ReadString('');
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\Explorer\EmptyRecycleBin\.Current',False) then
  Begin
   FEmptyRecycleBin:=ReadString('');
   CloseKey;
  End;


 Finally
  Free;
 End;
End;

procedure TSounds.Apply;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;
  If OpenKey('AppEvents\Schemes\Apps\.Default\.Default\.Current',True) then
  Begin
   WriteString('',FDefault);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\AppGPFault\.Current',True) then
  Begin
   WriteString('',FAppGPFault);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Maximize\.Current',True) then
  Begin
   WriteString('',FMaximize);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\MenuCommand\.Current',True) then
  Begin
   WriteString('',FMenuCommand);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\MenuPopup\.Current',True) then
  Begin
   WriteString('',FMenuPopup);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Minimize\.Current',True) then
  Begin
   WriteString('',FMinimize);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Open\.Current',True) then
  Begin
   WriteString('',FOpen);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Close\.Current',True) then
  Begin
   WriteString('',FClose);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RestoreDown\.Current',True) then
  Begin
   WriteString('',FRestoreDown);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RestoreUp\.Current',True) then
  Begin
   WriteString('',FRestoreUp);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\RingIn\.Current',True) then
  Begin
   WriteString('',FRingIn);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\Ringout\.Current',True) then
  Begin
   WriteString('',FRingout);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemAsterisk\.Current',True) then
  Begin
   WriteString('',FSystemAsterisk);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemDefault\.Current',True) then
  Begin
   WriteString('',FSystemDefault);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemExclamation\.Current',True) then
  Begin
   WriteString('',FSystemExclamation);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemExit\.Current',True) then
  Begin
   WriteString('',FSystemExit);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemHand\.Current',True) then
  Begin
   WriteString('',FSystemHand);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemQuestion\.Current',True) then
  Begin
   WriteString('',FSystemQuestion);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\.Default\SystemStart\.Current',True) then
  Begin
   WriteString('',FSystemStart);
   CloseKey;
  End;

  If OpenKey('AppEvents\Schemes\Apps\Explorer\EmptyRecycleBin\.Current',True) then
  Begin
   WriteString('',FEmptyRecycleBin);
   CloseKey;
  End;


 Finally
  Free;
 End;
End;


constructor TDesktop.Create;
Begin
  inherited Create;
End;

destructor TDesktop.Destroy;
Begin
  inherited Destroy;
End;

procedure TDesktop.Refresh;
Begin
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;

  If OpenKey('Control Panel\Desktop',False) then
  Begin

   If ValueExists('Wallpaper') then
    FWallpaper:=ReadString('Wallpaper') else
    FWallpaper:='';
   If ValueExists('Pattern') then
    FPattern :=ReadString('Pattern') else
    FPattern :='(None)';

   If StrToInt(ReadString('WallpaperStyle'))=2 then FWallpaperStyle:=wlpsStretch else
   If Boolean(StrToInt(ReadString('TileWallpaper'))) then FWallpaperStyle:=wlpsTile else
   FWallpaperStyle:=wlpsCenter;

   CloseKey;
  End;

 Finally
  Free;
 End;
End;

procedure TDesktop.Apply;
var
 buffer: array [0..255] of char;
 WindowsDir   : String;
Begin
 GetWindowsDirectory(@Buffer,SizeOf(buffer));
 WindowsDir:=Buffer;
 With TRegistry.Create do
 Try
  RootKey:=HKEY_CURRENT_USER;

  If OpenKey('Control Panel\Desktop',True) then
  Begin

{   If ValueExists('Wallpaper') then
    FWallpaper:=ReadString('Wallpaper') else
    FWallpaper:='';
   If ValueExists('Pattern') then
    FPattern :=ReadString('Pattern') else
    FPattern :='(None)';
 }

   WriteString('Pattern',FPattern);
   WriteString('Wallpaper',FWallpaper);
   
   If FWallpaperStyle=wlpsTile then
   Begin
    WriteString('TileWallpaper', '1');
    WriteString('WallpaperStyle', '0');
   End else
   If FWallpaperStyle=wlpsStretch then
   Begin
    WriteString('TileWallpaper', '0');
    WriteString('WallpaperStyle', '2');
   End else
   If FWallpaperStyle=wlpsCenter then
   Begin
    WriteString('TileWallpaper', '0');
    WriteString('WallpaperStyle', '0');
   End;
   
   CloseKey;
  End;

  SystemParametersInfo(SPI_SETDESKPATTERN,0, nil,spif_UpdateIniFile);

  If Uppercase(ExtractFileExt(FWallpaper))='.JPG' then
  Begin
   { Convert First }
   JPG2BMP(Fwallpaper,WindowsDir+'\WALL.BMP');
   FWallpaper:=WindowsDir+'\WALL.BMP';
  End;

  SystemParametersInfo(spi_SetDeskWallpaper, 0, PChar(FWallpaper), spif_UpdateIniFile);
 Finally
  Free;
 End;
End;

constructor TScreenSaver.Create;
Begin
  inherited Create;
End;

destructor TScreenSaver.Destroy;
Begin
  inherited Destroy;
End;

procedure TScreenSaver.Refresh;
var
 buffer: array [0..255] of char;
 Dir   : String;
 FIniFile: TIniFile;
Begin
 GetWindowsDirectory(@Buffer,SizeOf(buffer));
 Dir:=buffer;
 FiniFile:=TiniFile.Create(Dir+'\SYSTEM.INI');
 FScreenSaver:=FiniFile.ReadString('boot','SCRNSAVE.EXE','');
 FiniFile.free;
End;

Function Long2ShortFilename(Long:String):String;
var PathArray   : array [0..255] of char;
Begin
 GetShortPathName(Pchar(ExtractFilepath(Long)),@PathArray,255);
 Result:=PathArray+ExtractFilename(Long);
end;

procedure TScreenSaver.Apply;
var
 buffer: array [0..255] of char;
 Dir   : String;
 Flag  : Cardinal;
 FIniFile: TIniFile;
Begin
 GetWindowsDirectory(@Buffer,SizeOf(buffer));
 Dir:=buffer;
 FiniFile:=TiniFile.Create(Dir+'\SYSTEM.INI');
 FiniFile.WriteString('boot','SCRNSAVE.EXE',Long2ShortFilename(FScreenSaver));
 FiniFile.free;

 SystemParametersInfo(SPI_GETSCREENSAVEACTIVE,Flag,nil,0);
 SystemParametersInfo(SPI_SETSCREENSAVEACTIVE,Flag,nil,SPIF_SENDWININICHANGE);
End;


Procedure   TDesktopTheme.Apply;
Begin
  FCursors.Apply;
  FColors.Apply;
  FIcons.Apply;
  FSounds.Apply;
  FDesktop.Apply;
  FScreenSaver.Apply;
//  FMetrics.Apply;
  UpdateWindow;
End;

Procedure   TDesktopTheme.Refresh;
Begin
  FCursors.refresh;
  FColors.Refresh;
  FIcons.Refresh;
  FSounds.Refresh;
  FDesktop.Refresh;
  FScreenSaver.Refresh;
  FMetrics.Refresh;
end;

constructor TDesktopTheme.Create(AOwner: TComponent);
var
 buffer: array [0..255] of char;
 command:string;
begin
 inherited;

 FCursors:=tCursors.Create;
 FColors:=tColors.Create;
 FIcons:=tIcons.Create;
 FSounds:=tSounds.Create;
 FDesktop:=tDesktop.Create;
 FScreenSaver:=tScreenSaver.Create;
 FMetrics:=tMetrics.Create;

 Refresh;

 GetWindowsDirectory(@Buffer,SizeOf(buffer));
 WindowsDir:=Buffer;
 WindowsDir:=WindowsDir+'\';

 With TRegistry.Create do
 Try
  RootKey:=HKEY_CLASSES_ROOT;
  OpenKey('ThemeFile\Shell\Apply Settings\command',false);
  command:=readstring('');
  delete(command,pos('%1',command),length(command)-pos('%1',command)+1);
  If (Pos('PLUS!',Uppercase(command))<>0) and (Pos('THEMES.EXE',Uppercase(Command))<>0) then
  Begin
   { Plus Detected ... }
   PlusDir:=ExtractFileDir(Command)+'\';
   ThemesDir:=PlusDir+'Themes\';
  End;
 Finally
  free;
 end;
end;

destructor TDesktopTheme.Destroy;
begin
  FDesktop.Free;
  FSounds.Free;
  FCursors.Free;
  FColors.Free;
  FIcons.Free;
  FScreenSaver.Free;
  FMetrics.Free;
  inherited;
end;

Function WindowCallback(WHandle : HWnd; Var Parm : Pointer) : Boolean; stdcall;
begin
 SendMessage(WHandle,WM_SETTINGCHANGE,0,0);
 Result:=True;
end;

Procedure TDesktopTheme.UpdateWindow;
Begin
   EnumWindows(@WindowCallback,WM_SETTINGCHANGE);
End;

Function TDesktopTheme.InsertRealDir(Str:String):String;
begin
 Result:=ReplaceStr(Str,'%WinDir%',WindowsDir);
 Result:=ReplaceStr(Str,'%ThemeDir%',ThemesDir);
end;

Function TDesktopTheme.InsertVarDir(Str:String):String;
begin
 Result:=ReplaceStr(Str,WindowsDir,'%WinDir%');
 Result:=ReplaceStr(Str,ThemesDir,'%ThemeDir%');
end;

Procedure TDesktopTheme.LoadFromFile(Filename:String);
Begin
 With TIniFile.Create(Filename) do
 Try
  {Icons }
  Icons.MyComputer:=
  InsertRealDir(ReadString('CLSID\{20D04FE0-3AEA-1069-A2D8-08002B30309D}\DefaultIcon','DefaultValue',''));

  Icons.NetHood:=
  InsertRealDir(ReadString('CLSID\{208D2C60-3AEA-1069-A2D7-08002B30309D}\DefaultIcon','DefaultValue',''));

  Icons.RecycleFull:=
  InsertRealDir(ReadString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','full',''));

  Icons.RecycleEmpty:=
  InsertRealDir(ReadString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','empty',''));

  Icons.Recycle:=
  InsertRealDir(ReadString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','DefaultValue',''));
 
  Colors.ActiveTitle         :=ReadString('Control Panel\Colors','ActiveTitle','');
  Colors.Background          :=ReadString('Control Panel\Colors','Background','');
  Colors.Hilight             :=ReadString('Control Panel\Colors','Hilight','');
  Colors.HilightText         :=ReadString('Control Panel\Colors','HilightText','');
  Colors.TitleText           :=ReadString('Control Panel\Colors','TitleText','');
  Colors.Window              :=ReadString('Control Panel\Colors','Window','');
  Colors.WindowText          :=ReadString('Control Panel\Colors','WindowText','');
  Colors.Scrollbar           :=ReadString('Control Panel\Colors','Scrollbar','');
  Colors.InactiveTitle       :=ReadString('Control Panel\Colors','InactiveTitle','');
  Colors.Menu                :=ReadString('Control Panel\Colors','Menu','');
  Colors.WindowFrame         :=ReadString('Control Panel\Colors','WindowFrame','');
  Colors.MenuText            :=ReadString('Control Panel\Colors','MenuText','');
  Colors.ActiveBorder        :=ReadString('Control Panel\Colors','ActiveBorder','');
  Colors.InactiveBorder      :=ReadString('Control Panel\Colors','InactiveBorder','');
  Colors.AppWorkspace        :=ReadString('Control Panel\Colors','AppWorkspace','');
  Colors.ButtonFace          :=ReadString('Control Panel\Colors','ButtonFace','');
  Colors.ButtonShadow        :=ReadString('Control Panel\Colors','ButtonShadow','');
  Colors.GrayText            :=ReadString('Control Panel\Colors','GrayText','');
  Colors.ButtonText          :=ReadString('Control Panel\Colors','ButtonText','');
  Colors.InactiveTitleText   :=ReadString('Control Panel\Colors','InactiveTitleText','');
  Colors.ButtonHilight       :=ReadString('Control Panel\Colors','ButtonHilight','');
  Colors.ButtonDkShadow      :=ReadString('Control Panel\Colors','ButtonDkShadow','');
  Colors.ButtonLight         :=ReadString('Control Panel\Colors','ButtonLight','');
  Colors.InfoText            :=ReadString('Control Panel\Colors','InfoText','');
  Colors.InfoWindow          :=ReadString('Control Panel\Colors','InfoWindow','');

  Cursors.Arrow         := InsertRealDir(ReadString('Control Panel\Cursors','Arrow',''));
  Cursors.Help          := InsertRealDir(ReadString('Control Panel\Cursors','Help',''));
  Cursors.AppStarting   := InsertRealDir(ReadString('Control Panel\Cursors','AppStarting',''));
  Cursors.Wait          := InsertRealDir(ReadString('Control Panel\Cursors','Wait',''));
  Cursors.NWPen         := InsertRealDir(ReadString('Control Panel\Cursors','NWPen',''));
  Cursors.No            := InsertRealDir(ReadString('Control Panel\Cursors','No',''));
  Cursors.SizeNS        := InsertRealDir(ReadString('Control Panel\Cursors','SizeNS',''));
  Cursors.SizeWE        := InsertRealDir(ReadString('Control Panel\Cursors','SizeWE',''));
  Cursors.CrossHair     := InsertRealDir(ReadString('Control Panel\Cursors','Crosshair',''));
  Cursors.IBeam         := InsertRealDir(ReadString('Control Panel\Cursors','IBeam',''));
  Cursors.SizeNWSE      := InsertRealDir(ReadString('Control Panel\Cursors','SizeNWSE',''));
  Cursors.SizeNESW      := InsertRealDir(ReadString('Control Panel\Cursors','SizeNESW',''));
  Cursors.SizeAll       := InsertRealDir(ReadString('Control Panel\Cursors','SizeAll',''));
  Cursors.UpArrow       := InsertRealDir(ReadString('Control Panel\Cursors','UpArrow',''));

  Sounds.Default           := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\.Default\.Current','Default',''));
  Sounds.AppGPFault        := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\AppGPFault\.Current','AppGPFault',''));
  Sounds.Maximize          := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\Maximize\.Current','Maximize',''));
  Sounds.MenuCommand       := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\MenuCommand\.Current','MenuCommand',''));
  Sounds.MenuPopup         := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\MenuPopup\.Current','MenuPopup',''));
  Sounds.Minimize          := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\Minimize\.Current','Minimize',''));
  Sounds.Open              := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\Open\.Current','Open',''));
  Sounds.Close             := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\Close\.Current','Close',''));
  Sounds.RestoreDown       := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\RestoreDown\.Current','RestoreDown',''));
  Sounds.RestoreUp         := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\RestoreUp\.Current','RestoreUp',''));
  Sounds.RingIn            := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\RingIn\.Current','RingIn',''));
  Sounds.Ringout           := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\Ringout\.Current','Ringout',''));
  Sounds.SystemAsterisk    := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemAsterisk\.Current','SystemAsterisk',''));
  Sounds.SystemDefault     := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemDefault\.Current','SystemDefault',''));
  Sounds.SystemExclamation := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemExclamation\.Current','SystemExclamation',''));
  Sounds.SystemExit        := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemExit\.Current','SystemExit',''));
  Sounds.SystemHand        := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemHand\.Current','SystemHand',''));
  Sounds.SystemQuestion    := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemQuestion\.Current','SystemQuestion',''));
  Sounds.SystemStart       := InsertRealDir(ReadString('AppEvents\Schemes\Apps\.Default\SystemStart\.Current','SystemStart',''));
  Sounds.EmptyRecycleBin   := InsertRealDir(ReadString('AppEvents\Schemes\Apps\Explorer\EmptyRecycleBin\.Current','EmptyRecycleBin',''));

 
  ScreenSaver.ScreenSaver  := InsertRealDir(ReadString('boot','SCRNSAVE.EXE',''));

  Desktop.Wallpaper        := InsertRealDir(ReadString('Control Panel\Desktop','Desktop',''));
  Desktop.Pattern          := ReadString('Control Panel\Desktop','Pattern','(None)');

  If ReadInteger('Control Panel\Desktop', 'WallpaperStyle', 0)=2 then
   Desktop.WallpaperStyle:=wlpsStretch else
  If ReadBool('Control Panel\Desktop', 'TileWallpaper', False) then
   Desktop.WallpaperStyle:=wlpsTile else
   Desktop.WallpaperStyle:=wlpsCenter;

  Metrics.NonClientMetrics := ReadString('Metrics','NonclientMetrics','');
  Metrics.IconMetrics      := ReadString('Metrics','IconMetrics','');
 Finally
  Free;
 End;
End;

Procedure TDesktopTheme.SaveToFile  (Filename:String);
Begin
 With TIniFile.Create(Filename) do
 Try
  WriteString('CLSID\{20D04FE0-3AEA-1069-A2D8-08002B30309D}\DefaultIcon','DefaultValue',InsertVarDir(Icons.MyComputer));
  WriteString('CLSID\{208D2C60-3AEA-1069-A2D7-08002B30309D}\DefaultIcon','DefaultValue',InsertVarDir(Icons.NetHood));
  WriteString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','DefaultValue',InsertVarDir(Icons.Recycle));
  WriteString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','full',InsertVarDir(Icons.RecycleFull));
  WriteString('CLSID\{645FF040-5081-101B-9F08-00AA002F954E}\DefaultIcon','empty',InsertVarDir(Icons.RecycleEmpty));

  WriteString('Control Panel\Colors','ActiveTitle',Colors.ActiveTitle);
  WriteString('Control Panel\Colors','Background',Colors.Background);
  WriteString('Control Panel\Colors','Hilight',Colors.Hilight);
  WriteString('Control Panel\Colors','HilightText',Colors.HilightText);
  WriteString('Control Panel\Colors','TitleText',Colors.TitleText);
  WriteString('Control Panel\Colors','Window',Colors.Window);
  WriteString('Control Panel\Colors','WindowText',Colors.WindowText);
  WriteString('Control Panel\Colors','Scrollbar',Colors.Scrollbar);
  WriteString('Control Panel\Colors','InactiveTitle',Colors.InactiveTitle);
  WriteString('Control Panel\Colors','Menu',Colors.Menu);
  WriteString('Control Panel\Colors','WindowFrame',Colors.WindowFrame);
  WriteString('Control Panel\Colors','MenuText',Colors.MenuText);
  WriteString('Control Panel\Colors','ActiveBorder',Colors.ActiveBorder);
  WriteString('Control Panel\Colors','InactiveBorder',Colors.InactiveBorder);
  WriteString('Control Panel\Colors','AppWorkspace',Colors.AppWorkspace);
  WriteString('Control Panel\Colors','ButtonFace',Colors.ButtonFace);
  WriteString('Control Panel\Colors','ButtonShadow',Colors.ButtonShadow);
  WriteString('Control Panel\Colors','GrayText',Colors.GrayText);
  WriteString('Control Panel\Colors','ButtonText',Colors.ButtonText);
  WriteString('Control Panel\Colors','InactiveTitleText',Colors.InactiveTitleText);
  WriteString('Control Panel\Colors','ButtonHilight',Colors.ButtonHilight);
  WriteString('Control Panel\Colors','ButtonDkShadow',Colors.ButtonDkShadow);
  WriteString('Control Panel\Colors','ButtonLight',Colors.ButtonLight);
  WriteString('Control Panel\Colors','InfoText',Colors.InfoText);
  WriteString('Control Panel\Colors','InfoWindow',Colors.InfoWindow);

  WriteString('Control Panel\Cursors','Arrow',InsertVarDir(Cursors.Arrow));
  WriteString('Control Panel\Cursors','Help',InsertVarDir(Cursors.Help));
  WriteString('Control Panel\Cursors','AppStarting',InsertVarDir(Cursors.AppStarting));
  WriteString('Control Panel\Cursors','Wait',InsertVarDir(Cursors.Wait));
  WriteString('Control Panel\Cursors','NWPen',InsertVarDir(Cursors.NWPen));
  WriteString('Control Panel\Cursors','No',InsertVarDir(Cursors.No));
  WriteString('Control Panel\Cursors','SizeNS',InsertVarDir(Cursors.SizeNS));
  WriteString('Control Panel\Cursors','SizeWE',InsertVarDir(Cursors.SizeWE));
  WriteString('Control Panel\Cursors','CrossHair',InsertVarDir(Cursors.Crosshair));
  WriteString('Control Panel\Cursors','IBeam',InsertVarDir(Cursors.IBeam));
  WriteString('Control Panel\Cursors','SizeNWSE',InsertVarDir(Cursors.SizeNWSE));
  WriteString('Control Panel\Cursors','SizeNESW',InsertVarDir(Cursors.SizeNESW));
  WriteString('Control Panel\Cursors','SizeAll',InsertVarDir(Cursors.SizeAll));
  WriteString('Control Panel\Cursors','UpArrow',InsertVarDir(Cursors.UpArrow));
  WriteString('Control Panel\Cursors','Default Value','');

  WriteString('AppEvents\Schemes\Apps\.Default\.Default\.Current','Default',InsertVarDir(Sounds.Default));
  WriteString('AppEvents\Schemes\Apps\.Default\AppGPFault\.Current','AppGPFault',InsertVarDir(Sounds.AppGPFault));
  WriteString('AppEvents\Schemes\Apps\.Default\Maximize\.Current','Maximize',InsertVarDir(Sounds.Maximize));
  WriteString('AppEvents\Schemes\Apps\.Default\MenuCommand\.Current','MenuCommand',InsertVarDir(Sounds.MenuCommand));
  WriteString('AppEvents\Schemes\Apps\.Default\MenuPopup\.Current','MenuPopup',InsertVarDir(Sounds.MenuPopup));
  WriteString('AppEvents\Schemes\Apps\.Default\Minimize\.Current','Minimize',InsertVarDir(Sounds.Minimize));
  WriteString('AppEvents\Schemes\Apps\.Default\Open\.Current','Open',InsertVarDir(Sounds.Open));
  WriteString('AppEvents\Schemes\Apps\.Default\Close\.Current','Close',InsertVarDir(Sounds.Close));
  WriteString('AppEvents\Schemes\Apps\.Default\RestoreDown\.Current','RestoreDown',InsertVarDir(Sounds.RestoreDown));
  WriteString('AppEvents\Schemes\Apps\.Default\RestoreUp\.Current','RestoreUp',InsertVarDir(Sounds.RestoreUp));
  WriteString('AppEvents\Schemes\Apps\.Default\RingIn\.Current','RingIn',InsertVarDir(Sounds.RingIn));
  WriteString('AppEvents\Schemes\Apps\.Default\Ringout\.Current','Ringout',InsertVarDir(Sounds.Ringout));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemAsterisk\.Current','SystemAsterisk',InsertVarDir(Sounds.SystemAsterisk));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemDefault\.Current','SystemDefault',InsertVarDir(Sounds.SystemDefault));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemExclamation\.Current','SystemExclamation',InsertVarDir(Sounds.SystemExclamation));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemExit\.Current','SystemExit',InsertVarDir(Sounds.SystemExit));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemHand\.Current','SystemHand',InsertVarDir(Sounds.SystemHand));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemQuestion\.Current','SystemQuestion',InsertVarDir(Sounds.SystemQuestion));
  WriteString('AppEvents\Schemes\Apps\.Default\SystemStart\.Current','SystemStart',InsertVarDir(Sounds.SystemStart));
  WriteString('AppEvents\Schemes\Apps\Explorer\EmptyRecycleBin\.Current','EmptyRecycleBin',InsertVarDir(Sounds.EmptyRecycleBin));   

  WriteString('boot','SCRNSAVE.EXE',Long2ShortFilename(InsertVarDir(ScreenSaver.ScreenSaver)));

  WriteString('Control Panel\Desktop','Desktop',Desktop.Wallpaper );
  WriteString('Control Panel\Desktop','Pattern',Desktop.Pattern);

  if Desktop.WallpaperStyle=wlpsStretch then
  Begin
   WriteInteger('Control Panel\Desktop','WallpaperStyle',2);
   WriteBool('Control Panel\Desktop','TileWallpaper',False);
  End;

  If Desktop.WallpaperStyle=wlpsTile then
  Begin
   WriteInteger('Control Panel\Desktop','WallpaperStyle',0);
   WriteBool('Control Panel\Desktop','TileWallpaper',True);
  End;

  If Desktop.WallpaperStyle=wlpsCenter then
  Begin
   WriteInteger('Control Panel\Desktop','WallpaperStyle',0);
   WriteBool('Control Panel\Desktop','TileWallpaper',False);
  End;

  WriteString('Metrics','NonclientMetrics',Metrics.NonClientMetrics);
  WriteString('Metrics','IconMetrics',Metrics.IconMetrics);

 Finally
  Free;
 End;
End;

procedure Register;
begin
  RegisterComponents('Jazarsoft', [TDesktopTheme]);
end;

end.
